感謝您提供幫助讓我們的專案系統與服務更加安全 🤗

## 安全政策

我們非常重視我們的產品和服務的安全性，包含通過 `GitHub` 組織管理的原始碼與套件。

當您發現任何產品上的安全問題請立刻與我們聯絡，我們將盡速回報給各專案維護成員處理。

## 通報流程

如果您疑似發現了安全漏洞，請**不要**公開披露，請先給我們修復它的機會。

請**不要**通過 `GitHub` 的公開議題、討論或拉取請求報告安全漏洞。

請發送電子郵件至我們的[團隊信箱][mailto]。

請盡可能地完整呈述下面列出的資訊，以幫助我們更好地理解和解決問題：

- 💥 問題的類型（例如：緩衝區溢位、SQL隱碼或跨站腳本攻擊）
- 🗃️ 與問題相關的原始檔案完整路徑（或儲存庫名稱及相對路徑）
- 🚚 受影響原始碼的位置（ `tag` 、 `branch` 、 `commit hash` 或 `URL`）
- 🔧 重現問題所需的任何特殊設定（軟硬體環境、系統配置）
- 🩺 重現問題的步驟說明（如果可以請附上截圖）
- 🧪 有關問題的測試或攻擊程式碼（如果可能請提供概念驗證）
- 📝 問題的影響（包括攻擊者可能會如何利用該問題）

上述項目將幫助我們更快地對您的報告進行分類 😉

> [!NOTE]  
> 切勿嘗試對我們進行非技術性攻擊，例如：社會工程、網路釣魚。\
> 此外，調查問題需要一些時間，直到修復公開發表為止，請不要公開報告細節，以免被有心人士利用，再次感謝您的協助。

[mailto]: mailto:nicscda@nics.nat.gov.tw?subject=Report%20Security%20Vulnerability&body=👤%20通報人資訊%0A%20%20%20%20姓名%3A%20%20%20%20(先生/小姐)%0A%20%20%20%20所屬%3A%20%20%20%20(單位/組織)%0A%0A%0A💥%20問題的類型（例如：緩衝區溢位、SQL隱碼或跨站腳本攻擊）%0A%20%20%20%20%0A%0A🗃️%20與問題相關的原始檔案完整路徑（或儲存庫名稱及相對路徑）%0A%20%20%20%20%0A%0A🚚%20受影響原始碼的位置（tag、branch、commit%20hash或URL）%0A%20%20%20%20%0A%0A🔧%20重現問題所需的任何特殊設定（軟硬體環境、系統配置）%0A%20%20%20%20%0A%0A🩺%20重現問題的步驟說明（如果可以請附上截圖）%0A%20%20%20%20%0A%0A🧪%20有關問題的測試或攻擊程式碼（如果可能請提供概念驗證）%0A%20%20%20%20%0A%0A📝%20問題的影響（包括攻擊者可能會如何利用該問題）%0A%20%20%20%20%0A%0A
